//
//  SOMAAdMobBannerReceiver.m
//  Smaato
//
//  Copyright (c) 2018 Smaato Inc. All rights reserved.
//

#import <iSoma/iSoma.h>
#import "SOMAAdMobBannerReceiver.h"
#import <GoogleMobileAds/GoogleMobileAds.h>

@interface SOMAAdMobBannerReceiver()<GADCustomEventBanner, SOMAAdViewDelegate>
@property (nonatomic) SOMAAdView* adView;
@end

@implementation SOMAAdMobBannerReceiver

@synthesize delegate;

- (void)requestBannerAd:(GADAdSize)adSize
              parameter:(NSString *)serverParameter
                  label:(NSString *)serverLabel
                request:(GADCustomEventRequest *)request {
	
    // Determine correct SOMAAdDimension from GADAdSize
    SOMAAdDimension dimension;
    if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeBanner))) {
        dimension = SOMAAdDimensionXXLARGE;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeMediumRectangle))) {
        dimension = SOMAAdDimensionMedRect;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeLeaderboard))) {
        dimension = SOMAAdDimensionLeader;
    } else if (CGSizeEqualToSize(CGSizeFromGADAdSize(adSize), CGSizeFromGADAdSize(kGADAdSizeSkyscraper))) {
        dimension = SOMAAdDimensionSky;
    } else {
        dimension = SOMAAdDimensionDefault;
    }
    
    // Parse parameters
    NSMutableDictionary *adServerParameter = [[NSMutableDictionary alloc] init];
    NSArray *chunks = [[serverParameter lowercaseString] componentsSeparatedByString: @"&"];
    
    for (NSString *component in chunks) {
        NSArray *pair = [component componentsSeparatedByString:@"="];
        [adServerParameter setObject:[[pair objectAtIndex:1] stringByReplacingPercentEscapesUsingEncoding: NSMacOSRomanStringEncoding]
                        forKey:[pair objectAtIndex:0]]; 
    }
    
    // Create ad container
    self.adView = [[SOMAAdView alloc] init];
    CGRect rect = CGRectZero;
    rect.size = CGSizeFromGADAdSize(adSize);
    self.adView.frame = rect;
    self.adView.delegate  = self;
    
    // Apply ad settings
	self.adView.adSettings.type = SOMAAdTypeDisplay;
	self.adView.adSettings.dimension = dimension;
    self.adView.adSettings.autoReloadEnabled = NO;
    
    [self extractPublisherAndAdSpaceIDFromParameters:adServerParameter];

    // Optional: Pass location information
    self.adView.adSettings.longitude = request.userLongitude;
    self.adView.adSettings.latitude = request.userLatitude;
    
    // Optional: You can also set user profile targeting parameters by updating the `adView.adSettings.userProfile` object.
    // Please check the Smaato wiki for all available properties and further details.

	[self.adView load];
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.adView.adSettings.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.adView.adSettings.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.adView.adSettings.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.adView.adSettings.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"Ad"] intValue];
    }
}

#pragma mark - SOMAAdViewDelegate
- (UIViewController*)somaRootViewController {
    return self.delegate.viewControllerForPresentingModalView;
}

- (void)somaAdViewWillLoadAd:(SOMAAdView *)adview {
    
}

- (void)somaAdViewDidLoadAd:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventBanner:didReceiveAd:)]) {
        [self.delegate customEventBanner:self didReceiveAd:adview];
    }
}

- (void)somaAdView:(SOMAAdView*)adview didFailToReceiveAdWithError:(NSError *)error {
    if ([self.delegate respondsToSelector:@selector(customEventBanner:didFailAd:)]) {
        [self.delegate customEventBanner:self didFailAd:error];
    }
}

- (void)somaAdViewDidClick:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventBannerWasClicked:)]) {
        [self.delegate customEventBannerWasClicked:self];
    }
}

- (void)somaAdViewWillEnterFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventBannerWillPresentModal:)]) {
        [self.delegate customEventBannerWillPresentModal:self];
    }
}

- (void)somaAdViewDidEnterFullscreen:(SOMAAdView *)adview {

}

- (void)somaAdViewWillExitFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventBannerWillDismissModal:)]) {
        [self.delegate customEventBannerWillDismissModal:self];
    }
}

- (void)somaAdViewDidExitFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventBannerDidDismissModal:)]) {
        [self.delegate customEventBannerDidDismissModal:self];
    }
}

- (void)somaAdViewWillLeaveApplicationFromAd:(SOMAAdView *)adView {
    if ([self.delegate respondsToSelector:@selector(customEventBannerWillLeaveApplication:)]) {
        [self.delegate customEventBannerWillLeaveApplication:self];
    }
}

@end
