//
//  SOMAAdMobInterstitialReceiver.m
//  Smaato
//
//  Copyright (c) 2018 Smaato Inc. All rights reserved.
//

#import <iSoma/iSoma.h>
#import "SOMAAdMobInterstitialReceiver.h"
#import <GoogleMobileAds/GoogleMobileAds.h>

@interface SOMAAdMobInterstitialReceiver()<GADCustomEventInterstitial, SOMAAdViewDelegate>
@property (nonatomic) SOMAInterstitialAdView* interstitialAdView;
@end

@implementation SOMAAdMobInterstitialReceiver

@synthesize delegate;

- (void)requestInterstitialAdWithParameter:(NSString *)serverParameter
                                     label:(NSString *)serverLabel
                                   request:(GADCustomEventRequest *)request {
    
    // Parse parameters
	NSMutableDictionary *adServerParameter = [[NSMutableDictionary alloc] init];
	NSArray *chunks = [[serverParameter lowercaseString] componentsSeparatedByString: @"&"];
	
	for (NSString *component in chunks) {
		NSArray *pair = [component componentsSeparatedByString:@"="];
		[adServerParameter setObject:[[pair objectAtIndex:1] stringByReplacingPercentEscapesUsingEncoding: NSMacOSRomanStringEncoding]
							  forKey:[pair objectAtIndex:0]];
	}
	
    // Create ad container
    self.interstitialAdView = [[SOMAInterstitialAdView alloc] init];
    self.interstitialAdView.delegate = self;
    
    // Apply ad settings
	self.interstitialAdView.adSettings.type = SOMAAdTypeDisplay;
    self.interstitialAdView.adSettings.autoReloadEnabled = NO;

    [self extractPublisherAndAdSpaceIDFromParameters:adServerParameter];

    // Optional: Pass location information
    self.interstitialAdView.adSettings.longitude = request.userLongitude;
    self.interstitialAdView.adSettings.latitude = request.userLatitude;
    
    // Optional: You can also set user profile targeting parameters by updating the `adView.adSettings.userProfile` object.
    // Please check the Smaato wiki for all available properties and further details.

    dispatch_async(dispatch_get_main_queue(), ^{
        [self.interstitialAdView load];
    });
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.interstitialAdView.adSettings.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.interstitialAdView.adSettings.adSpaceId=[parameters[@"Ad"] intValue];
    }
}

- (void)presentFromRootViewController:(UIViewController *)rootViewController {
    self.interstitialAdView.rootViewController = rootViewController;
    [self.interstitialAdView show];
}

#pragma mark - SOMAAdViewDelegate
- (UIViewController*)somaRootViewController{
    return nil;
}

- (void)somaAdViewWillLoadAd:(SOMAAdView *)adview {
    
}

- (void)somaAdViewDidLoadAd:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialDidReceiveAd:)]) {
        [self.delegate customEventInterstitialDidReceiveAd:self];
    }
}

- (void)somaAdView:(SOMAAdView*)adview didFailToReceiveAdWithError:(NSError *)error {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitial:didFailAd:)]) {
        [self.delegate customEventInterstitial:self didFailAd:error];
    }
}

- (void)somaAdViewDidClick:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialWasClicked:)]) {
        [self.delegate customEventInterstitialWasClicked:self];
    }
}

- (void)somaAdViewWillEnterFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialWillPresent:)]) {
        [self.delegate customEventInterstitialWillPresent:self];
    }
}

- (void)somaAdViewDidEnterFullscreen:(SOMAAdView *)adview {
    
}

- (void)somaAdViewWillExitFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialWillDismiss:)]) {
        [self.delegate customEventInterstitialWillDismiss:self];
    }
}

- (void)somaAdViewDidExitFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialDidDismiss:)]) {
        [self.delegate customEventInterstitialDidDismiss:self];
    }
    if (adview == self.interstitialAdView) {
        [self.interstitialAdView removeFromSuperview];
        self.interstitialAdView.delegate = nil;
        self.interstitialAdView = nil;
    }
}

- (void)somaAdViewWillLeaveApplicationFromAd:(SOMAAdView *)adView {
    if ([self.delegate respondsToSelector:@selector(customEventInterstitialWillLeaveApplication:)]) {
        [self.delegate customEventInterstitialWillLeaveApplication:self];
    }
}

@end
