//
//  SOMAMoPubBannerAdapter.m
//  Smaato
//
//  Copyright (c) 2018 Smaato Inc. All rights reserved.
//

#import <iSoma/iSoma.h>
#import "SOMAMoPubBannerAdapter.h"
#import "MPAdView.h"

@interface SOMAMoPubBannerAdapter()<SOMAAdViewDelegate>
@property (nonatomic) SOMAAdView* adView;
@end

@implementation SOMAMoPubBannerAdapter
- (void)requestAdWithSize:(CGSize)size customEventInfo:(NSDictionary *)info {
    
    // Determine correct SOMAAdDimension from size
    SOMAAdDimension dimension;
    if (CGSizeEqualToSize(size, MOPUB_BANNER_SIZE)) {
        dimension = SOMAAdDimensionXXLARGE;
    } else if (CGSizeEqualToSize(size, MOPUB_MEDIUM_RECT_SIZE)) {
        dimension = SOMAAdDimensionMedRect;
    } else if (CGSizeEqualToSize(size, MOPUB_LEADERBOARD_SIZE)) {
        dimension = SOMAAdDimensionLeader;
    } else if (CGSizeEqualToSize(size, MOPUB_WIDE_SKYSCRAPER_SIZE)) {
        dimension = SOMAAdDimensionSky;
    } else {
        dimension = SOMAAdDimensionDefault;
    }
    
    // Create ad container
	self.adView = [[SOMAAdView alloc] initWithFrame:CGRectMake(0, 0, size.width, size.height)];
	self.adView.delegate = self;
	
    // Apply ad settings
    self.adView.adSettings.type = SOMAAdTypeDisplay;
    self.adView.adSettings.dimension = dimension;
    self.adView.adSettings.autoReloadEnabled = NO;
    
    [self extractPublisherAndAdSpaceIDFromParameters:info];

    // Optional: Pass location information
    CLLocation* location =  [self.delegate location];
    if (location) {
        self.adView.adSettings.longitude = location.coordinate.longitude;
        self.adView.adSettings.latitude = location.coordinate.latitude;
    }
    
    // Optional: You can also set user profile targeting parameters by updating the `adView.adSettings.userProfile` object.
    // Please check the Smaato wiki for all available properties and further details.
    
	[self.adView load];
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.adView.adSettings.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.adView.adSettings.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.adView.adSettings.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.adView.adSettings.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.adView.adSettings.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.adView.adSettings.adSpaceId=[parameters[@"Ad"] intValue];
    }
}

#pragma mark - SOMAAdViewDelegate
- (UIViewController*)somaRootViewController {
    return self.delegate.viewControllerForPresentingModalView;
}

- (void)somaAdViewWillLoadAd:(SOMAAdView *)adview {
    
}

- (void)somaAdViewDidLoadAd:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(bannerCustomEvent:didLoadAd:)]) {
        [self.delegate bannerCustomEvent:self didLoadAd:adview];
    }
}

- (void)somaAdView:(SOMAAdView*)adview didFailToReceiveAdWithError:(NSError *)error {
    if ([self.delegate respondsToSelector:@selector(bannerCustomEvent:didFailToLoadAdWithError:)]) {
        [self.delegate bannerCustomEvent:self didFailToLoadAdWithError:error];
    }
}

- (void)somaAdViewDidClick:(SOMAAdView *)adview {

}

- (void)somaAdViewWillEnterFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(bannerCustomEventWillBeginAction:)]) {
        [self.delegate bannerCustomEventWillBeginAction:self];
    }
}

- (void)somaAdViewDidEnterFullscreen:(SOMAAdView *)adview {
    
}

- (void)somaAdViewWillExitFullscreen:(SOMAAdView *)adview {

}

- (void)somaAdViewDidExitFullscreen:(SOMAAdView *)adview {
    if ([self.delegate respondsToSelector:@selector(bannerCustomEventDidFinishAction:)]) {
        [self.delegate bannerCustomEventDidFinishAction:self];
    }
}

- (void)somaAdViewWillLeaveApplicationFromAd:(SOMAAdView *)adView {
    if ([self.delegate respondsToSelector:@selector(bannerCustomEventWillLeaveApplication:)]) {
        [self.delegate bannerCustomEventWillLeaveApplication:self];
    }
}

@end
