//
//  SOMAMoPubNativeCustomEvent.m
//  Smaato
//
//  Copyright (c) 2018 Smaato Inc. All rights reserved.
//

#import <iSoma/iSoma.h>
#import "SOMAMoPubNativeCustomEvent.h"
#import "MPNativeAdConstants.h"
#import "SOMAMoPubNativeAdAdapter.h"
#import "MPNativeAd.h"

@interface SOMAMoPubNativeCustomEvent()
@property (nonatomic) SOMANativeAd* somaNativeAd;
@property (nonatomic, assign) NSInteger publisherId;
@property (nonatomic, assign) NSInteger adspaceId;
@end

@implementation SOMAMoPubNativeCustomEvent

- (void)requestAdWithCustomEventInfo:(NSDictionary *)info {

    [self extractPublisherAndAdSpaceIDFromParameters:info];

    self.somaNativeAd = [[SOMANativeAd alloc] init];
    self.somaNativeAd.adSettings.publisherId = self.publisherId;
    self.somaNativeAd.adSettings.adSpaceId = self.adspaceId;

    // Optional: You can also set user profile targeting parameters by updating the `adView.adSettings.userProfile` object.
    // Please check the Smaato wiki for all available properties and further details.
    
    __weak SOMAMoPubNativeCustomEvent* weakSelf = self;
    [self.somaNativeAd requestAd:^(SOMANativeAdObject *dto, NSError *error) {
        
        if (error != nil) {
            dispatch_async(dispatch_get_main_queue(), ^{
                if ([weakSelf.delegate respondsToSelector:@selector(nativeCustomEvent:didFailToLoadAdWithError:)]) {
                    [weakSelf.delegate nativeCustomEvent:weakSelf didFailToLoadAdWithError:error];
                }
            });
            return;
        }
        
        if (dto == nil) {
            dispatch_async(dispatch_get_main_queue(), ^{
                if ([weakSelf.delegate respondsToSelector:@selector(nativeCustomEvent:didFailToLoadAdWithError:)]) {
                    [weakSelf.delegate nativeCustomEvent:weakSelf didFailToLoadAdWithError:[NSError errorWithDomain:@"SOMAMoPubNativeCustomEventInvalidSOMAResponse" code:400 userInfo:nil]];
                }
            });
            return;
        }
        
        NSMutableDictionary* dic = [NSMutableDictionary new];
        dic[kAdTitleKey] = dto.title;
        dic[kAdTextKey] = dto.descriptionText;
        dic[kAdIconImageKey] = dto.assetIconURL.absoluteString;
        dic[kAdMainImageKey] = dto.assetMainURL.absoluteString;
        dic[kAdStarRatingKey] = [NSNumber numberWithFloat:dto.rating];
        dic[kAdCTATextKey] = dto.CTAText;
        dic[kDefaultActionURLKey] = dto.nativeURL.absoluteString;
        dic[kImpressionTrackerURLsKey] = dto.impressionTrackersUrls;
        dic[kClickTrackerURLKey] = dto.clickTrackersUrls;
        
        // collect imageURLs for preloading
        NSMutableArray *imageURLs = [[NSMutableArray alloc] init];
        if (dto.assetIconURL.absoluteString.length > 0) {
            [imageURLs addObject:dto.assetIconURL];
        }
        if (dto.assetMainURL.absoluteString.length > 0) {
            [imageURLs addObject:dto.assetMainURL];
        }
        
        [super precacheImagesWithURLs:imageURLs completionBlock:^(NSArray *errors) {
            dispatch_async(dispatch_get_main_queue(), ^{
                if (errors) {
                    if ([weakSelf.delegate respondsToSelector:@selector(nativeCustomEvent:didFailToLoadAdWithError:)]) {
                        [weakSelf.delegate nativeCustomEvent:weakSelf didFailToLoadAdWithError:[NSError errorWithDomain:@"SOMAMoPubNativeCustomEventDownloadingAssetsFailed" code:701 userInfo:nil]];
                    }
                } else {
                    if ([weakSelf.delegate respondsToSelector:@selector(nativeCustomEvent:didLoadAd:)]) {
                        SOMAMoPubNativeAdAdapter* adapter = [[SOMAMoPubNativeAdAdapter alloc] init:[dic copy] withDefaultActionURL:dto.nativeURL];
                        [weakSelf.delegate nativeCustomEvent:weakSelf didLoadAd:[[MPNativeAd alloc] initWithAdAdapter:adapter]];
                    }
                }
            });
        }];
    }];
}

- (void)extractPublisherAndAdSpaceIDFromParameters:(NSDictionary*)parameters {
    if ([[parameters allKeys] containsObject:@"pub"]) {
        self.publisherId=[parameters[@"pub"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisher"]) {
        self.publisherId=[parameters[@"publisher"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherid"]) {
        self.publisherId=[parameters[@"publisherid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherId"]) {
        self.publisherId=[parameters[@"publisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherId"]) {
        self.publisherId=[parameters[@"PublisherId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"PublisherID"]) {
        self.publisherId=[parameters[@"PublisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"publisherID"]) {
        self.publisherId=[parameters[@"publisherID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Publisher"]) {
        self.publisherId=[parameters[@"Publisher"] intValue];
    }
    
    if ([[parameters allKeys] containsObject:@"ad"]) {
        self.adspaceId=[parameters[@"ad"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspace"]) {
        self.adspaceId=[parameters[@"adspace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceid"]) {
        self.adspaceId=[parameters[@"adspaceid"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceId"]) {
        self.adspaceId=[parameters[@"adspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceId"]) {
        self.adspaceId=[parameters[@"AdspaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdspaceID"]) {
        self.adspaceId=[parameters[@"AdspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"adspaceID"]) {
        self.adspaceId=[parameters[@"adspaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceID"]) {
        self.adspaceId=[parameters[@"AdSpaceID"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpaceId"]) {
        self.adspaceId=[parameters[@"AdSpaceId"] intValue];
    } else if ([[parameters allKeys] containsObject:@"AdSpace"]) {
        self.adspaceId=[parameters[@"AdSpace"] intValue];
    } else if ([[parameters allKeys] containsObject:@"Ad"]) {
        self.adspaceId=[parameters[@"Ad"] intValue];
    }
}

@end
